@@ -29,7 +29,7 @@
 #include "applets.h"
 #include "timeanddate.h"
 #include "appmgr_setup.h"
-#include "ipaqscreen.h"
+#include "screen.h"
 #include "unimplemented.h"
 #include "kbd.h"
 #include "network.h"
@@ -90,14 +90,14 @@ struct Applet applets[]=
 		"Time" ,"time" ,"Time and Date Setup",PREFIX "/share/pixmaps/gpe-config-time.png"},
 /*    { &Appmgr_Build_Objects, &Appmgr_Free_Objects, &Appmgr_Save, &Appmgr_Restore , 
 		"Appmgr" ,"appmgr", "Launcher Setup", PREFIX "/share/pixmaps/gpe-config-appmgr.png"},
-*/    { &ipaqscreen_Build_Objects, &ipaqscreen_Free_Objects, &ipaqscreen_Save, &ipaqscreen_Restore,
-		"Screen" , "ipaqscreen", "Screen Setup", PREFIX "/share/pixmaps/gpe-config-ipaqscreen.png"},
+*/    { &screen_Build_Objects, &screen_Free_Objects, &screen_Save, &screen_Restore,
+		"Screen" , "screen", "Screen Setup", PREFIX "/share/pixmaps/gpe-config-screen.png"},
     { &Kbd_Build_Objects, &Unimplemented_Free_Objects, &Kbd_Save, &Kbd_Restore ,
 		"vKeyboard" ,"kbd", "Virtual Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-kbd.png"},
     { &Keyctl_Build_Objects, &Unimplemented_Free_Objects, &Keyctl_Save, &Keyctl_Restore ,
 		"Buttons" ,"keyctl", "Button Configuration",PREFIX "/share/pixmaps/gpe-config-keyctl.png"},
     { &Network_Build_Objects, &Network_Free_Objects, &Network_Save, &Network_Restore ,
-		"Network" ,"network","IP Addresses",PREFIX "/share/pixmaps/gpe-config-network.png"},
+		"Network" ,"network","Network Setup",PREFIX "/share/pixmaps/gpe-config-network.png"},
     { &Theme_Build_Objects, &Unimplemented_Free_Objects, &Theme_Save, &Theme_Restore ,
 		"Theme" ,"theme", "Look and Feel",PREFIX "/share/pixmaps/gpe-config-theme.png"},
     { &Sleep_Build_Objects, &Unimplemented_Free_Objects, &Sleep_Save, &Sleep_Restore ,
@@ -183,7 +183,6 @@ void item_select(int useronly, gpointer user_data)
   if(self.applet)
     {
       gtk_widget_hide(self.applet);
-      // TODO there must be a memory leak here..
       gtk_container_remove(GTK_CONTAINER(self.viewport),self.applet);
     }
   self.cur_applet = i;
