@@ -33,9 +33,9 @@
 #include "gpe-admin.h"
 #include "cfgfile.h"
 #include "ownerinfo.h"
-#include "ipaqscreen/brightness.h"
+#include "screen/brightness.h"
 #ifndef DISABLE_XRANDR
-#include "ipaqscreen/rotation.h"
+#include "screen/rotation.h"
 #endif
 #ifdef PACKAGETOOL		
 #include "packages.h"
@@ -359,13 +359,13 @@ suidloop (int write, int read)
 				else if (strcmp (cmd, "CPIF") == 0)  // installs a new interfaces file
 				{
 					fscanf (in, "%100s", arg2);	// to forget soon...
-					system ("/usr/bin/killall dhcpcd");
 					strcpy (arg1, "/tmp/interfaces");
 					strcpy (arg2, "/etc/network/interfaces");
-					system_printf ("/bin/cp %s %s", arg1,arg2);
+					system ("/etc/init.d/networking stop");
+					system_printf ("/bin/cp %s %s", arg1, arg2);
 					system_printf ("chmod 0644 %s", arg2);
 					system_printf ("/bin/rm -f %s", arg1);
-					system ("/etc/init.d/networking restart");
+					system ("/etc/init.d/networking start");
 				}
 				else if (strcmp (cmd, "CPOI") == 0)  // rewrites owner information data
 				{
@@ -378,9 +378,9 @@ suidloop (int write, int read)
 					system_printf ("/bin/rm -f %s",
 						       GPE_OWNERINFO_TMP);
 				}
-				else if (strcmp (cmd, "XCAL") == 0)  // runs xcalibrate
+				else if (strcmp (cmd, "XCAL") == 0)  // runs screen calibration tool
 				{
-					system ("/usr/bin/gpe-xcalibrate.sh");
+					system ("/usr/bin/xtscal");
 				}
 				else if (strcmp (cmd, "STZO") == 0)  // changes the timezone setting 
 				{
